@@ -29,13 +29,22 @@ def gen_cov_report(ip_str, is_regression=False, test_suite="", regression_name="
     dir_string = ""
     db_name_string = ""
     if is_regression:
-        cov_path    = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov"
-        merge_path  = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov/merge"
-        report_path = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov/report"
+        if test_suite == "":
+            cov_path    = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov"
+            merge_path  = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov/merge"
+            report_path = cfg.regr_results_dir + f"/{ip.name}__{regression_name}__{regression_timestamp}/cov/report"
+        else:
+            cov_path    = cfg.regr_results_dir + f"/{ip.name}__{test_suite}_{regression_name}__{regression_timestamp}/cov"
+            merge_path  = cfg.regr_results_dir + f"/{ip.name}__{test_suite}_{regression_name}__{regression_timestamp}/cov/merge"
+            report_path = cfg.regr_results_dir + f"/{ip.name}__{test_suite}_{regression_name}__{regression_timestamp}/cov/report"
     else:
         cov_path    = cfg.sim_dir + f"/cov"
+        merge_dir   = cfg.sim_dir + f"/cov/merge"
         merge_path  = cfg.sim_dir + f"/cov/merge/{ip.name}/"
+        report_dir  = cfg.sim_dir + f"/cov/reports/"
         report_path = cfg.sim_dir + f"/cov/reports/{ip.name}/"
+        common.create_dir(merge_dir)
+        common.create_dir(report_dir)
     common.create_dir(cov_path)
     common.create_dir(merge_path)
     common.create_dir(report_path)
