@@ -917,6 +917,13 @@ def do_simulate(ip, sim_job, wd):
         plus_args["UVMX_FILE_BASE_DIR_TB"          ] = ip.path + "/" + ip.src_path
         plus_args["UVMX_FILE_BASE_DIR_TESTS"       ] = ip.path + "/" + ip.src_path + "/" + ip.hdl_src_tests_path
     
+    if ip.has_targets:
+        if not sim_job.target_name in ip.targets:
+            common.fatal(f"IP '{ip.vendor}/{ip.name}' does not have specified target '{sim_job.target_name}'")
+        sim_args = ip.targets[sim_job.target_name].sim_args
+        for arg in sim_args:
+            plus_args[arg] = sim_args[arg]
+    
     plus_args_list = convert_plus_args(sim_job)
     if sim_job.simulator == common.simulators_enum.VIVADO:
         arg_list += plus_args_list
@@ -1156,7 +1163,25 @@ def gen_master_flist(ip, sim_job, deps, fsoc_core_name, fsoc_core_flist_path):
     else:
         if fsoc_core_flist_path != "":
             flists.insert(0, fsoc_core_flist_path)
-    gen_mflist_file(sim_job.simulator, ip.vendor, ip.name, flist_path, [], flists)
+    
+    defines = []
+    if ip.has_targets:
+        cmp_args = {}
+        if not sim_job.target_name in ip.targets:
+            common.fatal(f"IP '{ip.vendor}/{ip.name}' does not have specified target '{sim_job.target_name}'")
+        cmp_args = ip.targets[sim_job.target_name].cmp_args
+        for arg in cmp_args:
+            define = {}
+            define['name'] = arg
+            if cmp_args[arg] == "":
+                define['boolean'] = True
+                define['value'] = ""
+            else:
+                define['boolean'] = False
+                define['value'] = cmp_args[arg]
+            defines.append(define)
+    
+    gen_mflist_file(sim_job.simulator, ip.vendor, ip.name, flist_path, defines, flists)
     if sim_job.simulator == common.simulators_enum.METRICS:
         flist_path = os.path.relpath(flist_path, cfg.project_dir)
         #flist_path = flist_path.replace(cfg.project_dir, "")
