@@ -3,7 +3,7 @@
 ########################################################################################################################
 
 
-version = "1.1.5"
+version = "1.1.6"
 version_text = f"Moore.io CLI Client v{version}"
 
 
@@ -80,6 +80,8 @@ Examples:
 sim_help_text = """Moore.io Sim(ulation) Command
    Performs necessary steps to run simulation of an IP.  Only supports Digital Logic Simulation for the time being.
    
+   An optional target may be specified for the IP. Ex: my_ip#target.
+   
    While the controls for individual steps (FuseSoC processing, compilation, elaboration and simulation) are exposed, it
    is recommended to let `mio sim` manage this process as much as possible.  In the event of corrupt simulator
    artifacts, see `mio clean`.  Combining any of the step-control arguments (-F, -C, -E, -S) with missing steps can
@@ -109,15 +111,15 @@ Options:
    -F   Invoke FuseSoC to prepare core(s) for compilation.
    
 Examples:
-   mio sim uvmt_my_ip -t smoke -s 1 -w -c             # Compile, elaborate and simulate test 'uvmt_my_ip_smoke_test_c'
-                                                      # for IP 'uvmt_my_ip' with seed '1' and waves & coverage capture enabled.
-   mio sim uvmt_my_ip -t smoke -s 1 --args +NPKTS=10  # Compile, elaborate and simulate test 'uvmt_my_ip_smoke_test_c'
-                                                      # for IP 'uvmt_my_ip' with seed '1' and a simulation argument.
-   mio sim uvmt_my_ip -S -t smoke -s 42 -v high -g    # Only simulates test 'uvmt_my_ip_smoke_test_c' for IP 'uvmt_my_ip'
-                                                      # with seed '42' and UVM_HIGH verbosity using the simulator in GUI mode.
-   mio sim uvmt_my_ip -C                              # Only compile 'uvmt_my_ip'.
-   mio sim uvmt_my_ip -E                              # Only elaborate 'uvmt_my_ip'.
-   mio sim uvmt_my_ip -CE                             # Compile and elaborate 'uvmt_my_ip'."""
+   mio sim my_ip -t smoke -s 1 -w -c             # Compile, elaborate and simulate test 'my_ip_smoke_test_c'
+                                                 # for IP 'my_ip' with seed '1' and waves & coverage capture enabled.
+   mio sim my_ip -t smoke -s 1 --args +NPKTS=10  # Compile, elaborate and simulate test 'my_ip_smoke_test_c'
+                                                 # for IP 'my_ip' with seed '1' and a simulation argument.
+   mio sim my_ip -S -t smoke -s 42 -v high -g    # Only simulates test 'my_ip_smoke_test_c' for IP 'my_ip'
+                                                 # with seed '42' and UVM_HIGH verbosity using the simulator in GUI mode.
+   mio sim my_ip -C                              # Only compile 'my_ip'.
+   mio sim my_ip -E                              # Only elaborate 'my_ip'.
+   mio sim my_ip -CE                             # Compile and elaborate 'my_ip'."""
 
 
 
@@ -125,16 +127,18 @@ Examples:
 regr_help_text = """Moore.io Regr(ession) Command
    Runs a set of tests against a specific IP.  Regressions are described in Test Suite files (`[<target>.]ts.yml`).
    
+   An optional target may be specified for the IP. Ex: my_ip#target.
+   
 Usage:
-   mio regr IP [TARGET.]REGRESSION [OPTIONS]
+   mio regr IP [TEST SUITE.]REGRESSION [OPTIONS]
    
 Options:
    -d, --dry-run  Compiles, elaborates, but only prints the tests mio would normally run (does not actually run them).
    
 Examples:
-   mio regr uvmt_my_ip sanity            # Run sanity regression for IP 'uvm_my_ip', from test suite 'ts.yml'
-   mio regr uvmt_my_ip apb_xc.sanity     # Run sanity regression for IP 'uvm_my_ip', from test suite 'apb_xc.ts.yml'
-   mio regr uvmt_my_ip axi_xc.sanity -d  # Dry-run sanity regression for IP 'uvm_my_ip', from test suite 'axi_xc.ts.yml'"""
+   mio regr my_ip sanity            # Run sanity regression for IP 'uvm_my_ip', from test suite 'ts.yml'
+   mio regr my_ip apb_xc.sanity     # Run sanity regression for IP 'uvm_my_ip', from test suite 'apb_xc.ts.yml'
+   mio regr my_ip axi_xc.sanity -d  # Dry-run sanity regression for IP 'uvm_my_ip', from test suite 'axi_xc.ts.yml'"""
 
 
 
@@ -148,7 +152,7 @@ Usage:
 Options:
    
 Examples:
-   mio clean uvmt_my_ip  # Delete compilation, elaboration and simulation binaries for IP 'uvmt_my_ip'"""
+   mio clean my_ip  # Delete compilation, elaboration and simulation binaries for IP 'my_ip'"""
 
 
 
@@ -196,9 +200,9 @@ Options:
    -p PASSWORD, --password PASSWORD  # Specifies Moore.io password (must be combined with -u)
    
 Examples:
-   mio install uvmt_my_ip                          # Install IP dependencies for 'uvmt_my_ip' locally.
-   mio install uvmt_another_ip                     # Install IP dependencies for 'uvmt_another_ip' globally.
-   mio install uvmt_my_ip -u jenkins -p )Kq3)fkqm  # Specify credentials for Jenkins job."""
+   mio install my_ip                          # Install IP dependencies for 'my_ip' locally.
+   mio install another_ip                     # Install IP dependencies for 'another_ip' globally.
+   mio install my_ip -u jenkins -p )Kq3)fkqm  # Specify credentials for Jenkins job."""
 
 
 
