@@ -38,11 +38,10 @@ class TestSuite:
         self.timestamp         = datetime.now().strftime("%Y_%m_%d_%H_%M_%S")
         self.ip                = ip
         self.filepath          = filepath
+        self.filename          = ""
         self.name              = ""
         self.ip_name           = ""
-        self.cmp_args          = []
-        self.elab_args         = []
-        self.sim_args          = []
+        self.target_name       = "*"
         self.verbosity         = []
         self.sets              = {}
         self.regr              = {}
@@ -50,6 +49,7 @@ class TestSuite:
         self.cov               = []
         self.max_durations     = []
         self.max_jobs          = []
+        self.max_errors        = []
         if simulator == "viv":
             self.simulator = common.simulators_enum.VIVADO
         elif simulator == "mdc":
@@ -70,53 +70,22 @@ class TestSuite:
             common.fatal("No 'test-suite' entry!")
         common.dbg("Parsing test-suite metadata")
         
-        if 'info' not in yml['test-suite']:
-            common.fatal("No 'info' entry in 'test-suite'!")
-        common.dbg("Parsing test-suite info")
-        
-        if 'name' not in yml['test-suite']['info']:
+        if 'name' not in yml['test-suite']:
             common.fatal("No 'name' entry in 'test-suite'!")
-        self.name = yml['test-suite']['info']['name'].strip()
-        if not isinstance(self.name, str):
+        if not isinstance(yml['test-suite']['name'], str):
             common.fatal("'name' must be a string!")
+        self.name = yml['test-suite']['name'].strip()
         
-        if 'ip' not in yml['test-suite']['info']:
+        if 'ip' not in yml['test-suite']:
             common.fatal("No 'ip' entry in 'test-suite'!")
-        self.ip_name = yml['test-suite']['info']['ip'].strip().lower()
-        if not isinstance(self.ip_name, str):
-            common.fatal("'ip_name' must be a string!")
+        if not isinstance(yml['test-suite']['ip'], str):
+            common.fatal("'ip' must be a string!")
+        self.ip_name = yml['test-suite']['ip'].strip().lower()
         
         if 'target' in yml['test-suite']:
-            common.dbg("Parsing test-suite target")
-            if 'cmp-args' in yml['test-suite']['target']:
-                self.cmp_args = yml['test-suite']['target']['cmp-args']
-                if type(self.cmp_args) is not list and self.cmp_args != None:
-                    common.fatal("'cmp-args' must be a list!")
-                for arg in self.cmp_args:
-                    if not isinstance(arg, str):
-                        common.fatal("'cmp-args' entry key is not a string")
-                    if not isinstance(self.cmp_args[arg], str):
-                        common.fatal("'cmp-args' entry is not a string")
-            
-            if 'elab-args' in yml['test-suite']['target']:
-                self.elab_args = yml['test-suite']['target']['elab-args']
-                if type(self.elab_args) is not list and self.elab_args != None:
-                    common.fatal("'elab-args' must be a list!")
-                for arg in self.elab_args:
-                    if not isinstance(arg, str):
-                        common.fatal("'elab-args' entry key is not a string")
-                    if not isinstance(self.elab_args[arg], str):
-                        common.fatal("'elab-args' entry is not a string")
-            
-            if 'sim-args' in yml['test-suite']['target']:
-                self.sim_args = yml['test-suite']['target']['sim-args']
-                if type(self.sim_args) is not list and self.sim_args != None:
-                    common.fatal("'sim-args' must be a list!")
-                for arg in self.sim_args:
-                    if not isinstance(arg, str):
-                        common.fatal("'sim-args' entry key is not a string")
-                    if not isinstance(self.sim_args[arg], str):
-                        common.fatal("'sim-args' entry is not a string")
+            if not isinstance(yml['test-suite']['target'], str):
+                common.fatal("'target' must be a string!")
+            self.target_name = yml['test-suite']['target'].strip().lower()
         
         if 'settings' not in yml['test-suite']:
             common.fatal("No 'settings' entry in 'test-suite'!")
@@ -159,6 +128,18 @@ class TestSuite:
                     common.fatal("'max-duration' entry is not a number!")
         else:
             common.fatal("No 'max-duration' entry in test-suite settings!")
+            
+        if 'max-errors' in yml['test-suite']['settings']:
+            self.max_errors = yml['test-suite']['settings']['max-errors']
+            if type(self.max_durations) is not dict:
+                common.fatal("'max-errors' must be a dictionary!")
+            for errors in self.max_errors:
+                if not isinstance(errors, str):
+                    common.fatal("'max-errors' entry key is not a string!")
+                if not (type(self.max_errors[errors]) == int):
+                    common.fatal("'max-errors' entry is not an integer!")
+        else:
+            common.fatal("No 'max-errors' entry in test-suite settings!")
         
         if 'max-jobs' in yml['test-suite']['settings']:
             self.max_jobs = yml['test-suite']['settings']['max-jobs']
@@ -283,6 +264,9 @@ class TestSuite:
             #    common.fatal(f"'max-jobs' entry '{max}' is not a regression declared in this test suite")
             if max in self.regr:
                 self.regr[max].max_jobs = self.max_jobs[max]
+        for max in self.max_errors:
+            if max in self.regr:
+                self.regr[max].max_errors = self.max_errors[max]
     
     def add_test_set(self, set):
         if set.name in self.sets:
@@ -307,7 +291,6 @@ class TestSuite:
         sim_job.simulate  = False
         sim_job.gui       = False
         sim_job.simulator = self.simulator
-        sim_job.raw_args  = self.cmp_args
         if cfg.regression_name in self.waves:
             sim_job.waves = True
         else:
@@ -329,7 +312,6 @@ class TestSuite:
         sim_job.simulate  = False
         sim_job.gui       = False
         sim_job.simulator = self.simulator
-        sim_job.raw_args  = self.cmp_args
         if cfg.regression_name in self.waves:
             sim_job.waves = True
         else:
@@ -351,7 +333,6 @@ class TestSuite:
         sim_job.simulate  = False
         sim_job.gui       = False
         sim_job.simulator = self.simulator
-        sim_job.raw_args  = self.elab_args
         if cfg.regression_name in self.waves:
             sim_job.waves = True
         else:
@@ -363,10 +344,14 @@ class TestSuite:
         return sim_job
     
     def get_regression(self, regr_name):
+        if "." in regr_name:
+            empty_str = ""
+            empty_str, regr_name = regr_name.split(".")
+            regr_name = regr_name.replace(".", "")
         for reg in self.regr:
             if self.regr[reg].name == regr_name:
                 return self.regr[reg]
-        commmon.fatal(f"Could not find regression '{regr_name}'")
+        common.fatal(f"Could not find regression '{regr_name}'")
 
 
 class TestSet:
@@ -379,6 +364,7 @@ class TestSet:
         self.cov          = False
         self.max_duration = 1
         self.max_jobs     = 1
+        self.max_errors   = 1
         self.groups       = {}
     
     def add_test_group(self, group):
@@ -414,6 +400,7 @@ class Regression:
         self.suite        = suite
         self.max_duration = 0
         self.max_jobs     = 1
+        self.max_errors   = 1
     
     def add_test(self, name, seed, args):
         test = RegressionTest(name, self, self.group, self.set, self.suite, seed, args)
@@ -460,14 +447,14 @@ class RegressionTest:
         sim_job.is_regression   = True
         sim_job.regression_name = cfg.regression_name
         sim_job.regression_timestamp = self.suite.timestamp
-        sim_job.test      = self.name
-        sim_job.seed      = self.seed
-        sim_job.compile   = False
-        sim_job.elaborate = False
-        sim_job.simulate  = True
-        sim_job.gui       = False
-        sim_job.simulator = self.suite.simulator
-        sim_job.raw_args  = self.args
+        sim_job.test       = self.name
+        sim_job.seed       = self.seed
+        sim_job.compile    = False
+        sim_job.elaborate  = False
+        sim_job.simulate   = True
+        sim_job.gui        = False
+        sim_job.simulator  = self.suite.simulator
+        sim_job.max_errors = self.regression.max_errors
         if cfg.regression_name in self.suite.waves:
             sim_job.waves = True
         else:
@@ -501,7 +488,7 @@ class RegressionTest:
         return True
 
 
-def main(ip_str, regression, simulator, dry_mode):
+def main(ip_str, target_name, regression, simulator, dry_mode):
     vendor, name = common.parse_dep(ip_str)
     if vendor == "":
         ip = cache.get_anon_ip(name, True)
@@ -513,24 +500,27 @@ def main(ip_str, regression, simulator, dry_mode):
     
     timestamp_start = datetime.now()
     test_suite = scan_target_ip_for_test_suite(ip, simulator)
+    if test_suite.target_name != "*":
+        if test_suite.target_name != target_name:
+            common.fatal(f"Specified target '{target_name}' does not match test suite's {test_suite.target_name}")
     regression = test_suite.get_regression(cfg.cli_args.regr)
     regression.reduce()
     tests      = regression.get_tests()
-    prep_target_ip(ip, test_suite, simulator)
+    prep_target_ip(ip, target_name, test_suite, simulator)
     
     sim_job_list = []
     for test in tests:
         sim_job_list.append(test.get_sim_job())
     
-    launch_sim_jobs(ip, test_suite, regression, sim_job_list, dry_mode)
+    launch_sim_jobs(ip, target_name, test_suite, regression, sim_job_list, dry_mode)
     timestamp_end = datetime.now()
     if not dry_mode:
-        regr_results = results.main(f"{ip.vendor}/{ip.name}", "", True, test_suite.name, regression.name, test_suite.timestamp)
-        cov_report_path = cov.gen_cov_report(f"{ip.vendor}/{ip.name}", True, test_suite.name, regression.name, test_suite.timestamp)
+        regr_results = results.main(f"{ip.vendor}/{ip.name}", "", True, test_suite.filename, regression.name, test_suite.timestamp)
+        cov_report_path = cov.gen_cov_report(f"{ip.vendor}/{ip.name}", True, test_suite.filename, regression.name, test_suite.timestamp)
         print_end_of_regression_msg(ip, regr_results, cov_report_path, test_suite, regression, sim_job_list, timestamp_start, timestamp_end)
 
 
-def launch_sim_jobs(ip, test_suite, regression, sim_job_list, dry_mode):
+def launch_sim_jobs(ip, target_name, test_suite, regression, sim_job_list, dry_mode):
     global bar
     global sem
     global sem_cfg
@@ -546,6 +536,7 @@ def launch_sim_jobs(ip, test_suite, regression, sim_job_list, dry_mode):
     #common.create_dir(cfg.regr_results_dir + "/" + cfg.target_ip_name + "__" + regression_name + "__" + test_suite.timestamp)
     
     for sim_job in sim_job_list:
+        sim_job.target_name = target_name
         # TEMPORARY UNTIL METRICS REGRESSION SYSTEM IS LIVE
         if sim_job.simulator == common.simulators_enum.METRICS:
             launch_test(ip,test_suite,sim_job,dry_mode)
@@ -579,12 +570,13 @@ def timeout_process(hours):
     common.fatal(f"Regression timed out after {str(hours)} hour(s)")
 
 
-def prep_target_ip(ip, test_suite, simulator):
+def prep_target_ip(ip, target_name, test_suite, simulator):
     if cfg.test_suite_name != "":
         regression_name = cfg.test_suite_name + "_" + cfg.regression_name
     else:
         regression_name = cfg.regression_name
     gen_img_job = test_suite.get_gen_img_job()
+    gen_img_job.target_name     = target_name
     gen_img_job.regression_name = regression_name
     sim.main(gen_img_job)
 
@@ -638,7 +630,7 @@ def scan_target_ip_for_test_suite(ip, simulator):
     suite = None
     test_suite_name = ""
     if "." in cfg.regression_name:
-        split_string = regr_name.split(".")
+        split_string = cfg.regression_name.split(".")
         cfg.test_suite_name = split_string[0]
         cfg.regression_name = split_string[1]
         common.dbg(f"Test suite name is '{test_suite_name}' and regression name is '{cfg.regression_name}'")
@@ -661,11 +653,12 @@ def scan_target_ip_for_test_suite(ip, simulator):
                 if file.endswith(".ts.yml"):
                     filepath = dirpath + "/" + file
                     ts_name = file.replace(".ts.yml", "")
-                    ts_name = ts_name.replce(dirpath, "")
+                    ts_name = ts_name.replace(dirpath, "")
                     common.dbg(f"Found test suite '{ts_name}' descriptor file at {filepath}")
                     if ts_name == cfg.test_suite_name:
                         common.dbg(f"Found target test suite '{ts_name}' descriptor file at {filepath}")
                         suite = parse_test_suite_file(ip, simulator, filepath)
+                        suite.filename = ts_name
                         break
     if suite == None:
         common.fatal("Could not find test suite")
