@@ -77,7 +77,10 @@ def main(ip_str, filename="", is_regression=False, test_suite="", regression_nam
     results_model['testsuites'] = {}
     results_model['testsuites']['suites'] = []
     if is_regression:
-        results_model['testsuites']['name'] = snapshot + " '" + regression_name + "' regression"
+        if test_suite != "":
+            results_model['testsuites']['name'] = snapshot + f" '{test_suite}'" + " '" + regression_name + "' regression"
+        else:
+            results_model['testsuites']['name'] = snapshot + " '" + regression_name + "' regression"
     else:
         results_model['testsuites']['name'] = snapshot
     results_model['testsuites']['timestamp'] = timestamp
@@ -93,8 +96,12 @@ def main(ip_str, filename="", is_regression=False, test_suite="", regression_nam
                         if is_regression:
                             if not sim['is_regression']:
                                 continue
-                            if not sim["regression_name"] == regression_name:
-                                continue
+                            if test_suite != "":
+                                if not sim["regression_name"] == test_suite + "_" + regression_name:
+                                    continue
+                            else:
+                                if not sim["regression_name"] == regression_name:
+                                    continue
                             if not sim["regression_timestamp"] == regression_timestamp:
                                 continue
                         
@@ -144,7 +151,10 @@ def main(ip_str, filename="", is_regression=False, test_suite="", regression_nam
     testsuite.set('time', str(total_duration))
     tree = ET.ElementTree(testsuites)
     if is_regression:
-        xml_file_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression_name + "__" + regression_timestamp + "/" + filename + ".xml"
+        if test_suite != "":
+            xml_file_path = cfg.regr_results_dir + "/" + ip.name + "__" + test_suite + "_" + regression_name + "__" + regression_timestamp + "/" + filename + ".xml"
+        else:
+            xml_file_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression_name + "__" + regression_timestamp + "/" + filename + ".xml"
     else:
         xml_file_path = cfg.sim_dir + "/" + filename + ".xml"
     tree.write(xml_file_path)
@@ -169,7 +179,10 @@ def main(ip_str, filename="", is_regression=False, test_suite="", regression_nam
     
     try:
         if is_regression:
-            html_file_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression_name + "__" + regression_timestamp + "/" + filename + ".html"
+            if test_suite != "":
+                html_file_path = cfg.regr_results_dir + "/" + ip.name + "__" + test_suite + "_" + regression_name + "__" + regression_timestamp + "/" + filename + ".html"
+            else:
+                html_file_path = cfg.regr_results_dir + "/" + ip.name + "__" + regression_name + "__" + regression_timestamp + "/" + filename + ".html"
         else:
             html_file_path = cfg.sim_dir + "/" + filename + ".html"
         with open(html_file_path,'w') as htmlfile:
