@@ -87,6 +87,7 @@ class SimulationJob:
         self.cov             = False
         self.dry_run         = False
         self.raw_args        = []
+        self.target_name     = "default"
         self.cmp_args        = {}
         self.elab_args       = {}
         self.sim_args        = {}
@@ -123,6 +124,10 @@ def main(sim_job):
     if ip == None:
         common.fatal(f"Cannot find IP '{sim_job.vendor}/{sim_job.ip}'")
     ip_str = f"{ip.vendor}/{ip.name}"
+    if sim_job.target_name == "default":
+        ip_target_str = f"{ip.vendor}/{ip.name}"
+    else:
+        ip_target_str = f"{ip.vendor}/{ip.name}#{sim_job.target_name}"
     
     if sim_job.compile:
         if not ip.are_deps_installed():
@@ -180,7 +185,7 @@ def main(sim_job):
     
     if sim_job.compile and sim_job.elaborate:
         if sim_job.simulator == common.simulators_enum.VIVADO:
-            common.info(f"Compiling {ip_str} ...")
+            common.info(f"Compiling {ip_target_str} ...")
             est_time = get_ip_cmp_est(ip, sim_job)
             if est_time > 0:
                 pool = ThreadPool(processes=1)
@@ -191,7 +196,7 @@ def main(sim_job):
                 pool.join()
             else:
                 eal.cmp_ip(ip, sim_job, fsoc_core_name, fsoc_core_flist_path)
-            common.info(f"Elaborating {ip_str} ...")
+            common.info(f"Elaborating {ip_target_str} ...")
             est_time = get_ip_elab_est(ip, sim_job)
             if est_time > 0:
                 pool = ThreadPool(processes=1)
@@ -203,7 +208,7 @@ def main(sim_job):
             else:
                 eal.elab_ip(ip, sim_job)
         else:
-            common.info(f"Compiling+Elaborating {ip_str} ...")
+            common.info(f"Compiling+Elaborating {ip_target_str} ...")
             est_time = get_ip_gen_image_est(ip, sim_job)
             if est_time > 0:
                 pool = ThreadPool(processes=1)
@@ -215,7 +220,7 @@ def main(sim_job):
             else:
                 eal.gen_image_ip(ip, sim_job, fsoc_core_name, fsoc_core_flist_path)
     elif sim_job.compile:
-        common.info(f"Compiling {ip_str} ...")
+        common.info(f"Compiling {ip_target_str} ...")
         est_time = get_ip_cmp_est(ip, sim_job)
         if est_time > 0:
             pool = ThreadPool(processes=1)
@@ -227,7 +232,7 @@ def main(sim_job):
         else:
             eal.cmp_ip(ip, sim_job, fsoc_core_name, fsoc_core_flist_path)
     elif sim_job.elaborate:
-        common.info(f"Elaborating {ip_str} ...")
+        common.info(f"Elaborating {ip_target_str} ...")
         est_time = get_ip_elab_est(ip, sim_job)
         if est_time > 0:
             pool = ThreadPool(processes=1)
@@ -241,7 +246,7 @@ def main(sim_job):
     
     if not sim_job.is_regression:
         if sim_job.simulate:
-            common.banner(f"Simulating {ip_str} ...")
+            common.banner(f"Simulating {ip_target_str} ...")
             if sim_job.gui and sim_job.simulator == common.simulators_enum.METRICS:
                 common.warning("The Metrics Cloud Simulator does not support GUI mode")
             eal.simulate(ip, sim_job)
@@ -488,7 +493,11 @@ def bwrap_exclude(tar_info):
 def print_end_of_gen_image_message(ip, sim_job):
     if sim_job.dry_run:
         return
-    ip_str = f"{ip.name}"
+    if sim_job.target_name == "default":
+        ip_str = f"{ip.name}"
+    else:
+        ip_str = f"{ip.name}"
+        #ip_str = f"{ip.name}.{sim_job.target_name}"
     sim_str = common.get_simulator_short_name(sim_job.simulator)
     if sim_job.simulate:
         common.info("************************************************************************************************************************")
@@ -506,7 +515,11 @@ def print_end_of_gen_image_message(ip, sim_job):
 def print_end_of_compilation_message(ip, sim_job):
     if sim_job.dry_run:
         return
-    ip_str = f"{ip.name}"
+    if sim_job.target_name == "default":
+        ip_str = f"{ip.name}"
+    else:
+        ip_str = f"{ip.name}"
+        #ip_str = f"{ip.name}.{sim_job.target_name}"
     sim_str = common.get_simulator_short_name(sim_job.simulator)
     if sim_job.simulate or sim_job.elaborate:
         common.info("************************************************************************************************************************")
@@ -524,7 +537,11 @@ def print_end_of_compilation_message(ip, sim_job):
 def print_end_of_elaboration_message(ip, sim_job):
     if sim_job.dry_run:
         return
-    ip_str = f"{ip.name}"
+    if sim_job.target_name == "default":
+        ip_str = f"{ip.name}"
+    else:
+        ip_str = f"{ip.name}"
+        #ip_str = f"{ip.name}.{sim_job.target_name}"
     sim_str = common.get_simulator_short_name(sim_job.simulator)
     if sim_job.simulate:
         common.info("************************************************************************************************************************")
